ExtractByteRange

Enum ExtractByteRange 

pub enum ExtractByteRange {
    NotRequested,
    Requested,
    Found(Range<usize>),
}
Range extraction request/response

Variants



NotRequested

Range extraction was not requested



Requested

Range extraction was requested but not performed

This value is set upon entry to the extractor function. The function may replace the value with ExtractByteRange::Found if it supports finding byte ranges. If the extractor does not support byte ranges, it can ignore this value completely and leave it unchanged.



Found(Range<usize>)

Range extraction finished successfully

Note that for fields extracted from the plugin event data field, you will probably want to construct this value using ExtractByteRange::in_plugin_data.

Implementations

Source

impl ExtractByteRange

pub fn in_plugin_data(range: Range<usize>) -> Self

Create a range pointing into a plugin event data field

This is a helper for the common case of returning offsets inside the data field of a plugin event. It simply shifts the provided range by 38 bytes (26 header bytes, 2*4 length bytes, 4 plugin id bytes) to make the resulting range relative to the full event buffer.